import config from './auth-config.js';
import createAuth0Client from '@auth0/auth0-spa-js';
import { get } from 'svelte/store';
import { popupOpen, user, isAuthenticated, error, client } from '../store.js';
async function createClient() {
    const auth0Client = await createAuth0Client({
        domain: config.domain,
        client_id: config.clientId,
        redirect_uri: config.redirectUri
    });
    return auth0Client;
}
async function initializeAuth0() {
    client.set(await createClient());
    const auth0Client = get(client);
    isAuthenticated.set(await auth0Client.isAuthenticated());
    user.set((await auth0Client.getUser()));
}
async function loginWithPopup(options) {
    const auth0Client = get(client);
    popupOpen.set(true);
    try {
        await auth0Client.loginWithPopup(options);
        user.set((await auth0Client.getUser()));
        isAuthenticated.set(true);
    }
    catch (e) {
        console.error(e);
    }
    finally {
        popupOpen.set(false);
    }
}
function logout() {
    const auth0Client = get(client);
    return auth0Client.logout();
}
export function getUserValue() {
    return get(user);
}
export function getUser() {
    return user;
}
export function getIsAuthenticatedValue() {
    return get(isAuthenticated);
}
export function getIsAuthenticated() {
    return isAuthenticated;
}
export function getPopupOpenValue() {
    return get(popupOpen);
}
export function getPopupOpen() {
    return popupOpen;
}
export function getErrorValue() {
    return get(error);
}
export function getError() {
    return error;
}
const auth = {
    initializeAuth0,
    loginWithPopup,
    logout
};
export default auth;
